"""configuration file"""

APP_NAME: str = "flyswot"
MODEL_REPO_ID: str = "davanstrien/flyswot"
